@@ -83,7 +83,7 @@ namespace XrdCl
       }
     }
     pRunning = true;
-    log->Debug( JobMgrMsg, "Job manager started, %d workers", pWorkers.size() );
+    log->Debug( JobMgrMsg, "Job manager started, %llu workers", pWorkers.size() );
     return true;
   }
 
@@ -118,17 +118,21 @@ namespace XrdCl
     {
       void *threadRet;
       log->Dump( JobMgrMsg, "Stopping worker #%d...", i );
-      if( pthread_cancel( pWorkers[i] ) != 0 )
+      int rc = pthread_cancel( pWorkers[i] );
+      if( rc != 0 )
       {
         log->Error( TaskMgrMsg, "Unable to cancel worker #%d: %s", i,
                     XrdSysE2T( errno ) );
+        if( rc == ESRCH ) continue;
         abort();
       }
       
-      if( pthread_join( pWorkers[i], (void**)&threadRet ) != 0 )
+      rc = pthread_join( pWorkers[i], (void**)&threadRet );
+      if( rc != 0 )
       {
         log->Error( TaskMgrMsg, "Unable to join worker #%d: %s", i,
                     XrdSysE2T( errno ) );
+        if( rc == ESRCH ) continue;
         abort();
       }
 
